#! /usr/bin/env python
# -*- coding: utf-8 -*-
#########################################################################
# @File Name:    __init__.py
# @Author:	     kehr
# @Mail:		 kehr.china@gmail.com
# @Created Time: Wed 30 Apr 2014 11:01:53 AM CST
# @Copyright:    MIT applies
#########################################################################

__version__ = '0.1.4'
__author__  = 'kehr (kaixuan wang)'
__mail__    = 'kehr.china@gmail.com'
__license__ = 'MIT License: http://opensource.org/licenses/MIT'
__all__ = ['cli','upcloud','color','manual']    
